/*
*   $Id: ctags.h,v 1.3 2002/02/17 06:04:32 darren Exp $
*
*   Copyright (c) 1996-2002, Darren Hiebert
*
*   This source code is released for free distribution under the terms of the
*   GNU General Public License.
*
*   Program definitions
*/
#ifndef _CTAGS_H
#define _CTAGS_H

/*
*   MACROS
*/
#ifndef PROGRAM_VERSION
# define PROGRAM_VERSION "5.2.3"
#endif
#define PROGRAM_NAME	"Exuberant Ctags"
#define PROGRAM_URL	"http://ctags.sourceforge.net"
#define AUTHOR_NAME	"Darren Hiebert"
#define AUTHOR_EMAIL	"dhiebert@users.sourceforge.net"

#endif	/* _CTAGS_H */

/* vi:set tabstop=8 shiftwidth=4: */
